@@ -314,7 +314,7 @@ class SampleComponentObj:
         if self.sample_component_db == None:
             save_sample_component({
                 "sample": {"_id": self.sample_db["_id"], "name": self.sample_db["name"]},
-                "component": {"_id": self.component_db["_id"], "name": self.component_db["name"]},
+                "component": {"_id": self.component_db["_id"], "name": self.component_db["display_name"]},
                 "path": path,
                 "status": "initialized"
             })
@@ -322,7 +322,8 @@ class SampleComponentObj:
         self.initialized()
 
     def load(self):
-        return (self.sample_db["name"], self.component_db["name"], self.component_db["install"], self.component_db["options"], self.component_db["resources"])
+        #HACK: NOTE: Changed name to display name, obviously more needs to change. Leaving this here as a temp fix as the main fix is refactoring this object
+        return (self.sample_db["name"], self.component_db["display_name"], self.component_db["install"], self.component_db["options"], self.component_db["resources"])
 
     def start_data_extraction(self, file_location=None):
         summary = self.sample_component_db["properties"]["summary"]
@@ -373,15 +374,14 @@ class SampleComponentObj:
                 elif category == "component":
                     field = requirement.split(".")[2:]
                     expected_value = requirements[requirement]
-                    c_name = requirement.split(".")[1]
                     s_c_db = get_sample_component(sample_id=self.sample_id,
-                                                  component_name=c_name)
+                                                  component_id=self.component_id)
                     if not self.requirement_met(s_c_db, field, expected_value, log):
                         no_failures = False
                 else:
                     no_failures = False
         if no_failures:
-            open(os.path.join(self.component_db["name"], output_file), "w+").close()
+            open(os.path.join(self.component_db["display_name"], output_file), "w+").close()
         else:
             self.requirements_not_met()
 
@@ -399,7 +399,7 @@ class SampleComponentObj:
                 component["status"] = status
                 status_set = True
         if not status_set:
-            self.sample_db["components"].append({"_id": self.component_db["_id"], "name":self.component_db["name"], "status":status})
+            self.sample_db["components"].append({"_id": self.component_db["_id"], "name":self.component_db["display_name"], "status":status})
         self.save()
 
     def requirements_not_met(self):
@@ -430,7 +430,7 @@ class SampleComponentObj:
 
     def start_rule(self, rule_name, log=None):
         self.write_log_out(log, "{} has started\n".format(rule_name))
-        return (self.component_db["name"], self.component_db["options"], self.component_db["resources"])
+        return (self.component_db["display_name"], self.component_db["options"], self.component_db["resources"])
 
     def rule_run_cmd(self, command, log):
         self.write_log_out(log, "Running:{}\n".format(command))
@@ -469,7 +469,7 @@ class SampleComponentObj:
         self.write_log_out(log, "Files saved: {}\n".format(",".join(self.component_db["db_values_changes"]["files"])))
 
     def get_component_name(self):
-        return self.component_db["name"]
+        return self.component_db["display_name"]
 
     def run_data_dump_on_function(self, data_extraction_function, log=None):
         (self.sample_component_db["properties"]["summary"], self.sample_component_db["results"]) = data_extraction_function(self)
@@ -484,7 +484,7 @@ class SampleComponentObj:
         self.write_log_err(log, str(traceback.format_exc()))
         self.save()
         self.write_log_out(log, "sample {} saved\nsample_component {} saved\n".format(self.sample_db["_id"], self.sample_component_db["_id"]))
-        open(os.path.join(self.component_db["name"], output_file), "w+").close()
+        open(os.path.join(self.component_db["display_name"], output_file), "w+").close()
         self.write_log_out(log, "Done datadump\n")
         self.success()
 
